@@ -7,11 +7,11 @@ import pkg_resources
 import uvicorn
 from loguru import logger
 
-os.chdir(os.path.join(pkg_resources.get_distribution("b0mb3r").location, "b0mb3r"))
+os.chdir(os.path.join(pkg_resources.get_distribution("db0mb3r").location, "db0mb3r"))
 
-from b0mb3r.app.main import app
-from b0mb3r.service import prepare_services
-from b0mb3r.utils import open_url
+from db0mb3r.app.main import app
+from db0mb3r.service import prepare_services
+from db0mb3r.utils import open_url
 
 
 @logger.catch
